capture log close
clear all
macro drop _all
cd "C:\Users\alice\OneDrive\Alice QUANTONOMICS\Stata\DNSP MTFP Model Opt5"
set more off
log using crDNSPbench23-firm_op5, replace text

/*--------------------------------------------------------------------------
Project: Quantonomics DNSP Benchmarking
Author:  Michael Cunningham
File:    crDNSPbench22-firm_op5.do
Initial Date:    20-May-2022
Revised Date:	 11-Oct-2023
--------------------------------------------------------------------------*/

local varlist revenue energy customers maxdemand ratchetmd circlength cmos ///
	price_cmos opex price_opex overheadst overheadd undergrst undergrd ///
    transform auc_overheadst auc_overheadd auc_undergrst auc_undergrd  ///
	auc_transform  	

local datfiles EVOdata_op5.csv AGDdata_op5.csv CITdata_op5.csv ENDdata_op5.csv ///
	ENXdata_op5.csv ERGdata_op5.csv ESSdata_op5.csv JENdata_op5.csv PCRdata_op5.csv ///
	SAPdata_op5.csv ANDdata_op5.csv  TNDdata_op5.csv UEDdata_op5.csv

***	Read data ********

import excel using "Consolidated Data_11Oct2023.xlsx", ///
	sheet("Shazam DNSP Data") cellrange(A1:V223) clear firstrow case(l)
drop in 1
destring, replace	

***	Rename variables ********		
		
rename dnspyearidentifier			  dnspyear
rename totalrevenue                   revenue
rename customernumbers                customers	
rename maximumdemand                  maxdemand
rename ratchedmaximumdemand	          ratchetmd
rename circuitlength                  circlength	
rename customerminutesoffsupply       cmos	
rename pricecustomerminutesoffsuppl   price_cmos 	
rename priceopex                      price_opex	
rename overheadsubtransmissionlines   overheadst 	
rename overheaddistributionlinesund   overheadd
rename undergroundsubtransmissionline undergrst
rename undergrounddistributionlines   undergrd
rename transformersexcludingfirststa  transform
rename aucoverheadsubtransmission     auc_overheadst
rename aucoverheaddistribution        auc_overheadd
rename aucundergroundsubtransmission  auc_undergrst
rename aucundergrounddistribution     auc_undergrd
rename auctransformersexcludingfirst  auc_transform
rename shareofundergroundcables		  ucshare

***	Misc data management & save ********


gen int dnsp = int(dnspyear/100)
gen int year = dnspyear - dnsp*100 + 2000
	
replace cmos = 1 if cmos < 1

gen mdindex = 1
replace mdindex = (maxdemand / maxdemand[_n-1]) * mdindex[_n-1] if year > 2006
label variable mdindex      "Maximum demand index (2006 = 1)"		

format %14.0g `varlist'

label define dnsplab 1 "1.ACT: Evoenergy" 2 "2.AGD: Ausgrid" ///
	3 "3.CIT: CitiPower" 4 "4.END: Endeavour Energy" 5 "5.ENX: Energex" ///
	6 "6.ERG: Ergon Energy" 7 "7.ESS: Essential Energy" 8 "8.JEN: Jemena" ///
	9 "9.PCR: Powercor" 10 "10.SAP: SA Power Networks" ///
	11 "11.AND: AusNet Dist." 12 "12.TND: TasNetworks Dist." ///
	13 "13.UED: United Energy"																
label values dnsp dnsplab

sort dnsp year
xtset dnsp year

tab1 dnsp year
describe, f	
summarize `varlist' ucshare mdindex
misstable summarize `varlist' ucshare mdindex

save dnspbench23-firm_op5, replace

*** Create individual DNSP & pooled DNSP Shazam input data files ********
		
local j = 1	
foreach k of local datfiles {
	outsheet year `varlist' mdindex using `k' if dnsp == `j', comma replace
	local ++j
}

outsheet dnspyear `varlist' ucshare using DNSPdata_op5.csv, comma replace

log close
exit

