capture log close
clear all
macro drop _all
cd "C:\Users\alice\OneDrive\Alice QUANTONOMICS\Stata\DNSP Option5"
set more off
log using crDNSPbench23-firm1_opt5, replace text

/*--------------------------------------------------------------------------
Project: Quantonomics DNSP Benchmarking
Author:  Michael Cunningham
File:    crDNSPbench22-firm1.do
Initial Date:    20-May-2022
Revised Date:	 10-Aug-2023
--------------------------------------------------------------------------*/

local varlist revenue energy customers maxdemand ratchetmd circlength cmos ///
	price_cmos opex price_opex overheadst overheadd undergrst undergrd ///
    transform auc_overheadst auc_overheadd auc_undergrst auc_undergrd  ///
	auc_transform  	

local datfiles EVOdata5.csv AGDdata5.csv CITdata5.csv ENDdata5.csv ///
	ENXdata5.csv ERGdata5.csv ESSdata5.csv JENdata5.csv PCRdata5.csv ///
	SAPdata5.csv ANDdata5.csv TNDdata5.csv UEDdata5.csv

tempfile opt5opex	
	
*-------------------------------------------------------------------------	
	
import excel using "Master opex series_8Aug-2006-2022.xlsx", ///
	cellrange(D55:HP59) clear

*First row as variable names
foreach var of varlist * {
   local vname = strtoname(`var'[1])
   rename `var' `vname'
}
*Dropping the first two rows
drop in 1/4
gen var_i = 1
*export excel using test.xlsx, replace firstrow(var)	

reshape long _, i(var_i) j(dnspyear) string

gen year = ustrleft(dnspyear,4)
gen dnspname = ustrright(dnspyear,3)

rename _ opex
destring opex, replace
destring year, replace

gen int dnsp = .
replace dnsp = 1 if dnspname == "ACT" 
replace dnsp = 2 if dnspname == "AGD"
replace dnsp = 3 if dnspname == "CIT" 
replace dnsp = 4 if dnspname == "END" 
replace dnsp = 5 if dnspname == "ENX"
replace dnsp = 6 if dnspname == "ERG" 
replace dnsp = 7 if dnspname == "ESS" 
replace dnsp = 8 if dnspname == "JEN" 
replace dnsp = 9 if dnspname == "PCR" 
replace dnsp = 10 if dnspname == "SAP"
replace dnsp = 11 if dnspname == "AND" 
replace dnsp = 12 if dnspname == "TND"
replace dnsp = 13 if dnspname == "UED"	

drop var_i dnspyear dnspname
sort dnsp year
describe	
replace opex = opex/1000	
	
save `opt5opex'
	
***	Read data ********

import excel using "DNSP consolidated benchmarking data (2022).xlsx", ///
	sheet("Shazam DNSP Data") cellrange(A1:V223) clear firstrow case(l)
drop in 1
destring, replace	

***	Rename variables ********		
		
rename dnspyearidentifier			  dnspyear
rename totalrevenue                   revenue
rename customernumbers                customers	
rename maximumdemand                  maxdemand
rename ratchedmaximumdemand	          ratchetmd
rename circuitlength                  circlength	
rename customerminutesoffsupply       cmos	
rename pricecustomerminutesoffsuppl   price_cmos 	
rename priceopex                      price_opex	
rename overheadsubtransmissionlines   overheadst 	
rename overheaddistributionlinesund   overheadd
rename undergroundsubtransmissionline undergrst
rename undergrounddistributionlines   undergrd
rename transformersexcludingfirststa  transform
rename aucoverheadsubtransmission     auc_overheadst
rename aucoverheaddistribution        auc_overheadd
rename aucundergroundsubtransmission  auc_undergrst
rename aucundergrounddistribution     auc_undergrd
rename auctransformersexcludingfirst  auc_transform
rename shareofundergroundcables		  ucshare

***	Misc data management & save ********

gen int dnsp = int(dnspyear/100)
gen int year = dnspyear - dnsp*100 + 2000
	
replace cmos = 1 if cmos < 1

gen mdindex = 1
replace mdindex = (maxdemand / maxdemand[_n-1]) * mdindex[_n-1] if year > 2006
label variable mdindex      "Maximum demand index (2006 = 1)"		

format %14.0g `varlist'

label define dnsplab 1 "1.ACT: Evoenergy" 2 "2.AGD: Ausgrid" ///
	3 "3.CIT: CitiPower" 4 "4.END: Endeavour Energy" 5 "5.ENX: Energex" ///
	6 "6.ERG: Ergon Energy" 7 "7.ESS: Essential Energy" 8 "8.JEN: Jemena" ///
	9 "9.PCR: Powercor" 10 "10.SAP: SA Power Networks" ///
	11 "11.AND: AusNet Dist." 12 "12.TND: TasNetworks Dist." ///
	13 "13.UED: United Energy"																
label values dnsp dnsplab

sort dnsp year

merge 1:1 dnsp year using `opt5opex', update replace
drop _merge

xtset dnsp year

tab1 dnsp year
describe, f	
summarize `varlist' ucshare mdindex
misstable summarize `varlist' ucshare mdindex

save dnspbench23-firm_op5, replace

*** Create individual DNSP & pooled DNSP Shazam input data files ********
/*		
local j = 1	
foreach k of local datfiles {
	outsheet year `varlist' mdindex using `k' if dnsp == `j', comma replace
	local ++j
}

outsheet dnspyear `varlist' ucshare using DNSPdata5.csv, comma replace*/

log close
exit

